@@ -18,12 +18,18 @@ import packaging.utils
 import requests
 
 import concurrent.futures
+import datetime
 import json
 import logging
 import multiprocessing
 import pkgutil
 import re
 
+try:
+    from functools import lru_cache
+except ImportError:
+    from backports.functools_lru_cache import lru_cache
+
 
 
 try:
@@ -42,6 +48,17 @@ def just_name(supposed_name):
 def manual_overrides():
     """Read the overrides file.
 
+    Read the overrides from cache, if available. Otherwise, an attempt is made
+    to read the file as it currently stands on GitHub, and then only if that
+    fails is the included file used. The result is cached for one day.
+    """
+    return _manual_overrides(datetime.date.today())
+
+
+@lru_cache(maxsize=1)
+def _manual_overrides(_cache_date=None):
+    """Read the overrides file.
+
     An attempt is made to read the file as it currently stands on GitHub, and
     then only if that fails is the included file used.
     """
@@ -49,10 +66,10 @@ def manual_overrides():
     request = requests.get("https://raw.githubusercontent.com/brettcannon/"
                            "caniusepython3/master/caniusepython3/overrides.json")
     if request.status_code == 200:
-        log.info("Overrides loaded from GitHub")
+        log.info("Overrides loaded from GitHub and cached")
         overrides = request.json()
     else:
-        log.info("Overrides loaded from included package data")
+        log.info("Overrides loaded from included package data and cached")
         raw_bytes = pkgutil.get_data(__name__, 'overrides.json')
         overrides = json.loads(raw_bytes.decode('utf-8'))
     return frozenset(map(packaging.utils.canonicalize_name, overrides.keys()))
